#[non_exhaustive]pub enum InlinePolicy {
Never,
LeafIfFits(usize),
}Expand description
When maps and sequences are written on a single line in indented output.
Maps and sequences with the Layout::Compact
hint are always written on a single line, the ones with
Layout::Expanded never (unless they are in a
map or sequence on a single line). See SerializerConfig::set_inline.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Never
Only compact maps and sequences are written on a single line.
LeafIfFits(usize)
Maps and sequences which only contain scalars (no maps or sequences, not even empty ones) are written on a single line if that line is not longer than the given number of characters (including the indentation, a tab counts as one character).